@@ -897,8 +897,8 @@ class Commit(object):
             **{
                 "publisher": account,
                 "exchange_rate": {
-                    "base": "%s HBD" % hive_usd_price,
-                    "quote": "%s HIVE" % quote,
+                    "base": "%s SBD" % hive_usd_price,
+                    "quote": "%s STEEM" % quote,
                 },
             }
         )
@@ -927,7 +927,7 @@ class Commit(object):
             raise ValueError("You need to provide an account")
 
         try:
-            PublicKey(signing_key)
+            PublicKey(signing_key, prefix=self.hived.chain_params["prefix"])
         except Exception as e:
             raise e
 
@@ -937,7 +937,7 @@ class Commit(object):
                 "url": url,
                 "block_signing_key": signing_key,
                 "props": props,
-                "fee": "0.000 HIVE",
+                "fee": "0.000 STEEM",
                 "prefix": self.hived.chain_params["prefix"],
             }
         )
