@@ -904,5 +904,47 @@ class CommentOptions(GrapheneObject):
             )
 
 
+class AccountUpdate2(GrapheneObject):
+    def __init__(self, *args, **kwargs):
+        if isArgsThisClass(self, args):
+            self.data = args[0].data
+        else:
+            if len(args) == 1 and len(kwargs) == 0:
+                kwargs = args[0]
+
+            meta = ""
+            if "json_metadata" in kwargs and kwargs["json_metadata"]:
+                if isinstance(kwargs["json_metadata"], dict) or isinstance(
+                    kwargs["json_metadata"], list
+                ):
+                    meta = json.dumps(kwargs["json_metadata"])
+                else:
+                    meta = kwargs["json_metadata"]
+
+            posting_meta = ""
+            if "posting_json_metadata" in kwargs and kwargs["posting_json_metadata"]:
+                if isinstance(kwargs["posting_json_metadata"], dict) or isinstance(
+                    kwargs["posting_json_metadata"], list
+                ):
+                    posting_meta = json.dumps(kwargs["posting_json_metadata"])
+                else:
+                    posting_meta = kwargs["posting_json_metadata"]
+
+            super(AccountUpdate2, self).__init__(
+                OrderedDict(
+                    [
+                        ("account", String(kwargs["account"])),
+                        ("owner", Optional(None)),
+                        ("active", Optional(None)),
+                        ("posting", Optional(None)),
+                        ("memo_key", Optional(None)),
+                        ("json_metadata", String(meta)),
+                        ("posting_json_metadata", String(posting_meta)),
+                        ("extensions", Array([])),
+                    ]
+                )
+            )
+
+
 def isArgsThisClass(self, args):
     return len(args) == 1 and type(args[0]).__name__ == type(self).__name__
